@@ -476,6 +476,22 @@ class Core(metaclass=SingletonType):
         self.__flag_start = False
         self.__repeat_key = None
 
+    def get_flag_run(self):
+        return self.__flag_run
+
+    def set_flag_run(self, flag):
+        self.__flag_run = flag
+
+    def get_current_config(self):
+        return list(self.__configs.keys()).index(self.__current_config)
+
+    def set_current_config(self, ind):
+        if not isinstance(ind, int):
+            raise TypeError('index must be integer')
+        if ind >= len(self.__configs):
+            raise RuntimeError('index out of range')
+        self.__current_config = list(self.__configs.keys())[ind]
+
     def add_window(self, window):
         """
         添加窗体实例
@@ -631,3 +647,6 @@ class Core(metaclass=SingletonType):
         :return:
         """
         self.__pool.submit(self.__show, text, duration)
+
+    flag_run = property(get_flag_run, set_flag_run)
+    current_config = property(get_current_config, set_current_config)
